Update model — BAGO 0.0.1 documentation

# Update model

This function is implemented in the `gpModel` class to update the model with new data.

updateModel(self, exp, parameters)

  Function to update the model with new data.

  Parameters:

    - exp – dict. A dictionary of LC-MS experiemnts. Key is the name of the experiment and value is a `MSData` object.

    - parameters – dict. A dictionary of parameters.

To use this function:

    # You need a gpModel object (model).

    model.updateModel(exp, parameters)